BleDeviceCubit class

Cubit for BLE device management

This cubit manages BLE device scanning, connection and communication with GK Concept BLE devices. It emits the following states:

Constructors

BleDeviceCubit()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isClosed → bool
Whether the bloc is closed.
no setterinherited
mockDevices → List<BluetoothDevice>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → BleDeviceState
The current state.
no setterinherited
stream → Stream<BleDeviceState>
The current stream of states.
no setterinherited

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
close() → Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
connect(BluetoothDevice device) → Future<void>
Connect to a BLE device.
disconnect() → Future<void>
Disconnect from the device
discoverServices() → Future<void>
Discover services of the connected device
emit(BleDeviceState state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
getRssi(BluetoothDevice device) → int
Get the cached RSSI value of a device.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Change<BleDeviceState> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
startScanning() → Future<void>
Start scanning for BLE devices.
stopScanning() → Future<void>
Stop scanning for BLE devices.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

logger → Logger
final